@@ -1,13 +1,15 @@
-#include "../config.h"
-
-#include <gnome.h>
+#include <config.h>
+#include <string.h>
 #include <bonobo-activation/bonobo-activation.h>
 #include <libgnomevfs/gnome-vfs.h>
+#include <libgnomeui/gnome-client.h>
+#include <libgnomeui/gnome-ui-init.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <gconf/gconf-client.h>
 #include <bonobo.h>
 #include <bonobo/bonobo-ui-main.h>
 #include "eog-window.h"
+#include "session.h"
 
 static gboolean
 create_app (gpointer data)
@@ -146,33 +148,64 @@ enum {
  *
  * @Return value: TRUE, if a collection should be used, else FALSE.
  * */
+#ifdef EOG_COLLECTION_WORKS
+
 static gint
 user_wants_collection (gint n_windows)
 {
 	GtkWidget *dlg;
 	gint ret;
-	gchar *msg;
-	
-	msg = g_new0(gchar, 120);
-	g_snprintf (msg, 120, 
-		    _("You are about to open %i windows\n"
-		      "simultanously. Do you want to open\n"
-		      "them in a collection instead?"),
-		    n_windows);
-	
-	dlg = gnome_message_box_new (msg,
-				     GNOME_MESSAGE_BOX_QUESTION,
-				     GNOME_STOCK_BUTTON_CANCEL,
-				     _("Single Windows"), _("Collection"), 
-				     NULL);		
-	ret = gnome_dialog_run (GNOME_DIALOG (dlg));
-	g_free (msg);
 
-	if (ret == -1) ret = COLLECTION_CANCEL;
+	dlg = gtk_message_dialog_new (NULL,
+				      GTK_DIALOG_MODAL,
+				      GTK_MESSAGE_QUESTION,
+				      GTK_BUTTONS_CANCEL,
+				      _("You are about to open %i windows\n"
+					"simultanously. Do you want to open\n"
+					"them in a collection instead?"),
+				      n_windows);
+	
+	gtk_dialog_add_button (GTK_DIALOG (dlg), _("Single Windows"), COLLECTION_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dlg), _("Collection"), COLLECTION_YES);
+
+	ret = gtk_dialog_run (GTK_DIALOG (dlg));
+
+	if (ret != COLLECTION_NO && ret != COLLECTION_YES) 
+		ret = COLLECTION_CANCEL;
+
+	gtk_widget_destroy (dlg);
 
 	return ret;
 }
 
+#else
+
+static gint
+user_wants_collection (gint n_windows)
+{
+	GtkWidget *dlg;
+	gint ret;
+	
+	dlg = gtk_message_dialog_new (NULL,
+				      GTK_DIALOG_MODAL,
+				      GTK_MESSAGE_QUESTION,
+				      GTK_BUTTONS_CANCEL,
+				      _("You are about to open %i windows\n"
+					"simultanously. Do you want to continue?"),
+				      n_windows);
+	gtk_dialog_add_button (GTK_DIALOG (dlg), _("Open"), COLLECTION_NO);
+
+	ret = gtk_dialog_run (GTK_DIALOG (dlg));
+
+	if (ret != COLLECTION_NO)
+		ret = COLLECTION_CANCEL;
+
+	gtk_widget_destroy (dlg);
+
+	return ret;
+}
+#endif /* EOG_COLLECTION WORKS */
+
 /**
  * handle_cmdline_args:
  * @data: Pointer to the popt context provided by gnome_init_with_popt_table.
@@ -191,10 +224,10 @@ handle_cmdline_args (gpointer data)
 	GList *dir_list = NULL;
 	GList *file_list = NULL;
 	const gchar **startup_files;
-	poptContext *ctx;
+	poptContext ctx;
 
-	ctx = (poptContext*) data;
-	startup_files = poptGetArgs (*ctx);
+	ctx = data;
+	startup_files = poptGetArgs (ctx);
 
 	/* sort cmdline arguments into file and dir list */
 	if (startup_files)
@@ -206,10 +239,6 @@ handle_cmdline_args (gpointer data)
 
 	/* open regular files */
 	if (file_list != NULL) {
-		/* FIXME: The collection view is not yet ported to Gnome2 so 
-		 * we must disable the following stuff :-(.
-		 */
-#if 0
 		if (g_list_length (file_list) > 3) {
 			gint ret = user_wants_collection (g_list_length (file_list));
 			if (ret == COLLECTION_YES) {
@@ -223,8 +252,7 @@ handle_cmdline_args (gpointer data)
 				g_list_free (file_list);
 			} else { /* quit whole program */
 				GList *node;
-				poptFreeContext (*ctx);
-				g_free (ctx);
+				poptFreeContext (ctx);
 				for (node = file_list; node; node = node->next) g_free (node->data);
 				for (node = dir_list; node; node = node->next) g_free (node->data);
 				g_list_free (file_list);
@@ -233,12 +261,9 @@ handle_cmdline_args (gpointer data)
 				return FALSE;
 			}
 		} else {
-#endif
 			open_in_single_windows (file_list);
 			g_list_free (file_list);
-#if 0
 		}
-#endif
 	}
 		
 	/* open every directory in an own window */
@@ -248,29 +273,71 @@ handle_cmdline_args (gpointer data)
 	}
 	
 	/* clean up */
-	poptFreeContext (*ctx);
-	g_free (ctx);
+	poptFreeContext (ctx);
 
 	return FALSE;
 }
 
+/* Callback used when the session manager asks us to save our state */
+static gboolean
+client_save_yourself_cb (GnomeClient *client,
+			 gint phase,
+			 GnomeSaveStyle save_style,
+			 gboolean shutdown,
+			 GnomeInteractStyle interact_style,
+			 gboolean fast,
+			 gpointer data)
+{
+	const char *prefix;
+
+	prefix = gnome_client_get_config_prefix (client);
+	session_save (prefix);
+
+	return TRUE;
+}
+
+/* Callback used when the session manager asks us to terminate.  We simply exit
+ * the application by destroying all open windows.
+ */
+static void
+client_die_cb (GnomeClient *client, gpointer data)
+{
+	GList *l;
+
+	do {
+		l = eog_get_window_list ();
+		if (l) {
+			EogWindow *window;
+
+			window = EOG_WINDOW (l->data);
+			gtk_widget_destroy (GTK_WIDGET (window));
+		}
+	} while (l);
+}
+
 int
 main (int argc, char **argv)
 {
-	CORBA_Environment ev;
-	CORBA_ORB orb;
+	GnomeProgram *program;
 	GError *error;
-	poptContext *ctx;
+	poptContext ctx;
+	GValue value = { 0 };
+	GnomeClient *client;
 
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (PACKAGE, "UTF-8");
 	textdomain (PACKAGE);
 
+#if 0
+
 	ctx = g_new0 (poptContext, 1);
 	gnome_init_with_popt_table ("Eye of Gnome", VERSION,
 		    argc, argv, NULL, 0, ctx);
-
-	CORBA_exception_init (&ev);
+#endif
+	program = gnome_program_init ("eog", VERSION,
+				      LIBGNOMEUI_MODULE, argc, argv,
+				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Eye of Gnome"),
+				      NULL);
 
 	error = NULL;
 	if (gconf_init (argc, argv, &error) == FALSE) {
@@ -286,16 +353,25 @@ main (int argc, char **argv)
 	if (bonobo_ui_init ("Eye Of GNOME", VERSION, &argc, argv) == FALSE)
 		g_error (_("Could not initialize Bonobo!\n"));
 
-	if (*ctx) {
-		gtk_idle_add (handle_cmdline_args, ctx);
-	} else
-		gtk_idle_add (create_app, NULL);
-
 	gnome_window_icon_set_default_from_file (EOG_ICONDIR"/gnome-eog.png");
 
+	client = gnome_master_client ();
+
+	g_signal_connect (client, "save_yourself", G_CALLBACK (client_save_yourself_cb), NULL);
+	g_signal_connect (client, "die", G_CALLBACK (client_die_cb), NULL);
+
+	if (gnome_client_get_flags (client) & GNOME_CLIENT_RESTORED)
+		session_load (gnome_client_get_config_prefix (client));
+	else {
+		g_value_init (&value, G_TYPE_POINTER);
+		g_object_get_property (G_OBJECT (program), GNOME_PARAM_POPT_CONTEXT, &value);
+		ctx = g_value_get_pointer (&value);
+		g_value_unset (&value);
+
+		gtk_idle_add (handle_cmdline_args, ctx);
+	}
+
 	bonobo_main ();
 
-	CORBA_exception_free (&ev);
-	
 	return 0;
 }
