@@ -12,12 +12,13 @@
 
 #include <config.h>
 #include <stdio.h>
+#include <string.h>
+#include <glib/gstrfuncs.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkmarshal.h>
 #include <gtk/gtktypeutils.h>
 #include <gconf/gconf-client.h>
 
-#include <gnome.h>
 #include <libgnomeprint/gnome-print-master.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
@@ -45,6 +46,10 @@ struct _EogImageViewPrivate {
 	EogImage              *image;
 
 	GConfClient	      *client;
+	guint                 interp_type_notify_id;
+	guint                 dither_notify_id;
+	guint                 check_type_notify_id;
+	guint                 check_size_notify_id;
 
 	GtkWidget             *ui_image;
         ImageView             *image_view;
@@ -107,7 +112,7 @@ image_set_image_cb (EogImage *eog_image, EogImageView *image_view)
 	   axis, this needs fixing in src/image-view.c */
 /*	if (image_view->priv->zoom_fit); */
 		image_view_set_pixbuf (image_view->priv->image_view, pixbuf);
-		gdk_pixbuf_unref (pixbuf);
+		g_object_unref (pixbuf);
 
 		ui_image_fit_to_screen (UI_IMAGE (image_view->priv->ui_image));
 	}
@@ -120,9 +125,8 @@ listener_Interpolation_cb (BonoboUIComponent           *uic,
 			   const char                  *state,
 			   gpointer                     user_data)
 {
-	BonoboArg *arg;
 	EogImageView *image_view;
-	GNOME_EOG_Interpolation interpolation;
+	GdkInterpType interpolation;
 
 	g_return_if_fail (user_data != NULL);
 	g_return_if_fail (EOG_IS_IMAGE_VIEW (user_data));
@@ -135,27 +139,26 @@ listener_Interpolation_cb (BonoboUIComponent           *uic,
 
 	image_view = EOG_IMAGE_VIEW (user_data);
 
-	if (!strcmp (path, "InterpolationNearest"))
-		interpolation = GNOME_EOG_INTERPOLATION_NEAREST;
-	else if (!strcmp (path, "InterpolationTiles"))
-		interpolation = GNOME_EOG_INTERPOLATION_TILES;
-	else if (!strcmp (path, "InterpolationBilinear"))
-		interpolation = GNOME_EOG_INTERPOLATION_BILINEAR;
-	else if (!strcmp (path, "InterpolationHyperbolic"))
-		interpolation = GNOME_EOG_INTERPOLATION_HYPERBOLIC;
+	if (!strcmp (path, "InterpolationNearest")) {
+		interpolation = GDK_INTERP_NEAREST;
+	}
+	else if (!strcmp (path, "InterpolationTiles")) {
+		interpolation = GDK_INTERP_TILES;
+	}
+	else if (!strcmp (path, "InterpolationBilinear")) {
+		interpolation = GDK_INTERP_BILINEAR;
+	}
+	else if (!strcmp (path, "InterpolationHyperbolic")) {
+		interpolation = GDK_INTERP_HYPER;
+	}
 	else {
 		g_warning ("Unknown interpolation type `%s'", path);
 		return;
 	}
 
-	arg = bonobo_arg_new (TC_GNOME_EOG_Interpolation);
-	BONOBO_ARG_SET_GENERAL (arg, interpolation, TC_GNOME_EOG_Interpolation,
-				GNOME_EOG_Interpolation, NULL);
-
-	bonobo_pbclient_set_value (BONOBO_OBJREF (image_view->priv->property_bag),
-				   "interpolation", arg, NULL);
-
-	bonobo_arg_release (arg);
+	gconf_client_set_int (image_view->priv->client, 
+			      GCONF_EOG_VIEW_INTERP_TYPE, 
+			      (int) interpolation, NULL);
 }
 
 static void
@@ -167,7 +170,6 @@ listener_Dither_cb (BonoboUIComponent           *uic,
 {
 	EogImageView *image_view;
 	GNOME_EOG_Dither dither;
-	BonoboArg *arg;
 
 	g_return_if_fail (user_data != NULL);
 	g_return_if_fail (EOG_IS_IMAGE_VIEW (user_data));
@@ -191,14 +193,9 @@ listener_Dither_cb (BonoboUIComponent           *uic,
 		return;
 	}
 
-	arg = bonobo_arg_new (TC_GNOME_EOG_Dither);
-	BONOBO_ARG_SET_GENERAL (arg, dither, TC_GNOME_EOG_Dither,
-				GNOME_EOG_Dither, NULL);
-
-	bonobo_pbclient_set_value (BONOBO_OBJREF (image_view->priv->property_bag),
-				       "dither", arg, NULL);
-
-	bonobo_arg_release (arg);
+	gconf_client_set_int (image_view->priv->client, 
+			      GCONF_EOG_VIEW_DITHER, 
+			      (int) dither, NULL);
 }
 
 static void
@@ -210,7 +207,6 @@ listener_CheckType_cb (BonoboUIComponent           *uic,
 {
 	EogImageView *image_view;
 	GNOME_EOG_CheckType check_type;
-	BonoboArg *arg;
 
 	g_return_if_fail (user_data != NULL);
 	g_return_if_fail (EOG_IS_IMAGE_VIEW (user_data));
@@ -240,14 +236,9 @@ listener_CheckType_cb (BonoboUIComponent           *uic,
 		return;
 	}
 
-	arg = bonobo_arg_new (TC_GNOME_EOG_CheckType);
-	BONOBO_ARG_SET_GENERAL (arg, check_type, TC_GNOME_EOG_CheckType,
-				GNOME_EOG_CheckType, NULL);
-
-	bonobo_pbclient_set_value (BONOBO_OBJREF (image_view->priv->property_bag),
-				       "check_type", arg, NULL);
-
-	bonobo_arg_release (arg);
+	gconf_client_set_int (image_view->priv->client, 
+			      GCONF_EOG_VIEW_CHECK_TYPE, 
+			      (int) check_type, NULL);
 }
 
 static void
@@ -256,7 +247,7 @@ filesel_ok_cb (GtkWidget* ok_button, gpointer user_data)
 	EogImageView     *image_view;
 	GtkWidget        *fsel;
 	const gchar      *filename;
-	gchar            *message = NULL;
+	char             *message;
 	CORBA_Environment ev;
 	Bonobo_Storage    storage = CORBA_OBJECT_NIL;
 	Bonobo_Stream     stream = CORBA_OBJECT_NIL;
@@ -264,6 +255,7 @@ filesel_ok_cb (GtkWidget* ok_button, gpointer user_data)
 	gchar            *path_base = NULL;
         gchar            *mime_type = NULL;
 	gchar            *tmp_dir = NULL;
+	GtkWidget        *dialog;
 
 	g_return_if_fail (user_data != NULL);
 	g_return_if_fail (EOG_IS_IMAGE_VIEW (user_data));
@@ -305,14 +297,19 @@ filesel_ok_cb (GtkWidget* ok_button, gpointer user_data)
 	return;
 
  on_error:
-	message = g_strdup_printf (
+	dialog = gtk_message_dialog_new (
+		GTK_WINDOW (fsel), GTK_DIALOG_MODAL,
+		GTK_MESSAGE_ERROR,
+		GTK_BUTTONS_CLOSE,
 		_("Could not save image as '%s': %s."), filename, 
-		bonobo_exception_get_text (&ev));
-	gnome_error_dialog_parented (message, GTK_WINDOW (fsel));
+		(message = bonobo_exception_get_text (&ev)));
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+
 	g_free (message);
-	if (path_dir) g_free (path_dir);
-	if (path_base) g_free (path_base);
-	if (mime_type) g_free (mime_type);
+	g_free (path_dir);
+	g_free (path_base);
+	g_free (mime_type);
 
 	if (stream != CORBA_OBJECT_NIL)
 		bonobo_object_release_unref (stream, &ev);
@@ -356,10 +353,10 @@ verb_SaveAs_cb (BonoboUIComponent *uic, gpointer user_data, const char *name)
 	image_view = EOG_IMAGE_VIEW (user_data);
 
 	filesel = GTK_FILE_SELECTION (gtk_file_selection_new (_("Save As")));
-	gtk_signal_connect (GTK_OBJECT (filesel->ok_button), "clicked", 
-			    GTK_SIGNAL_FUNC (filesel_ok_cb), image_view);
-	gtk_signal_connect (GTK_OBJECT (filesel->cancel_button), "clicked", 
-			    GTK_SIGNAL_FUNC (filesel_cancel_cb), image_view);
+	g_signal_connect (filesel->ok_button, "clicked", 
+			  G_CALLBACK (filesel_ok_cb), image_view);
+	g_signal_connect (filesel->cancel_button, "clicked", 
+			  G_CALLBACK (filesel_cancel_cb), image_view);
 	gtk_widget_show (GTK_WIDGET (filesel));
 }
 
@@ -563,6 +560,7 @@ verb_Send_cb (BonoboUIComponent *uic, gpointer user_data, const char *name)
  * Start of printing related code 
  * ***************************************************************************/
 
+#if 0 
 static gint
 count_pages (gdouble 	paper_width,
 	     gdouble	paper_height,
@@ -601,6 +599,7 @@ count_pages (gdouble 	paper_width,
 
 	return (cols * rows);
 }
+#endif
 
 static void
 print_line (GnomePrintContext *context, 
@@ -821,7 +820,7 @@ print_page (GnomePrintContext 	*context,
 					      gdk_pixbuf_get_height (pixbuf_to_print),
 					      gdk_pixbuf_get_rowstride (pixbuf_to_print));
 
-		gdk_pixbuf_unref (pixbuf_to_print);
+		g_object_unref (pixbuf_to_print);
 		gnome_print_grestore (context);
 		
 		/* Helpers? */
@@ -1002,7 +1001,7 @@ eog_image_view_print (EogImageView *image_view, gboolean preview,
 
 	/* Scale the pixbuf */
 	pixbuf = gdk_pixbuf_scale_simple (pixbuf_orig, width, height, interp);
-	gdk_pixbuf_unref (pixbuf_orig);
+	g_object_unref (pixbuf_orig);
 
 	/* Print it! */
 	print_page (print_context, 
@@ -1014,7 +1013,7 @@ eog_image_view_print (EogImageView *image_view, gboolean preview,
 		    fit_to_page, adjust_to,
 		    down_right, cut, overlap_x, overlap_y, overlap,
 		    pixbuf, 0, 0);
-	gdk_pixbuf_unref (pixbuf);
+	g_object_unref (pixbuf);
 
 	gnome_print_context_close (print_context);
 	gnome_print_master_close (print_master);
@@ -1118,7 +1117,6 @@ listener_CheckSize_cb (BonoboUIComponent           *uic,
 {
 	EogImageView *image_view;
 	GNOME_EOG_CheckSize check_size;
-	BonoboArg *arg;
 
 	g_return_if_fail (user_data != NULL);
 	g_return_if_fail (EOG_IS_IMAGE_VIEW (user_data));
@@ -1142,22 +1140,69 @@ listener_CheckSize_cb (BonoboUIComponent           *uic,
 		return;
 	}
 
-	arg = bonobo_arg_new (TC_GNOME_EOG_CheckSize);
-	BONOBO_ARG_SET_GENERAL (arg, check_size, TC_GNOME_EOG_CheckSize,
-				GNOME_EOG_CheckSize, NULL);
-
-	bonobo_pbclient_set_value (BONOBO_OBJREF (image_view->priv->property_bag),
-				       "check_size", arg, NULL);
-
-	bonobo_arg_release (arg);
+	gconf_client_set_int (image_view->priv->client, 
+			      GCONF_EOG_VIEW_CHECK_SIZE, 
+			      (int) check_size, NULL);
 }
 
+
+static const gchar* ui_id_strings_interp_type [] = {
+	"InterpolationNearest",
+	"InterpolationTiles",
+	"InterpolationBilinear",
+	"InterpolationHyperbolic"
+};
+
+static const gchar* ui_id_strings_dither [] = {
+	"DitherNone",
+	"DitherNormal",
+	"DitherMaximum"
+};
+
+static const gchar* ui_id_strings_check_type [] = {
+	"CheckTypeDark",
+	"CheckTypeMidtone",
+	"CheckTypeLight",
+	"CheckTypeBlack",
+	"CheckTypeGray",
+	"CheckTypeWhite"
+};
+
+static const gchar* ui_id_strings_check_size [] = {
+	"CheckSizeSmall",
+	"CheckSizeMedium",
+	"CheckSizeLarge"
+};
+
+static void
+set_ui_group_item (EogImageView *image_view, const gchar *group_cmd)
+{
+	gchar *path;
+	gchar *value;
+	
+	path = g_strconcat ("/commands/", group_cmd, NULL);
+
+	value = bonobo_ui_component_get_prop (image_view->priv->uic,
+					      path, "state", NULL);
+	if (value == NULL || !g_ascii_strcasecmp (value, "0")) {
+		bonobo_ui_component_set_prop (image_view->priv->uic, 
+					      path, "state", "1", NULL);
+	}
+
+	g_free (value);
+	g_free (path);
+}
+
+
 #define EVOLUTION_MENU "<menuitem name=\"Send\" _label=\"Send\" pixtype=\"stock\" pixname=\"New Mail\" verb=\"\"/>"
 #define GNOCAM_MENU "<menuitem name=\"AcquireFromCamera\" _label=\"Acquire from camera\" verb=\"\"/>"
 
 static void
 eog_image_view_create_ui (EogImageView *image_view)
 {
+	int value;
+	int i;
+
 	g_return_if_fail (image_view != NULL);
 	g_return_if_fail (EOG_IS_IMAGE_VIEW (image_view));
 
@@ -1176,32 +1221,42 @@ eog_image_view_create_ui (EogImageView *image_view)
 					   GNOCAM_MENU, NULL);
 #endif
 
-	bonobo_ui_component_add_listener (image_view->priv->uic, "InterpolationNearest",
-					  listener_Interpolation_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "InterpolationTiles",
-					  listener_Interpolation_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "InterpolationBilinear",
-					  listener_Interpolation_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "InterpolationHyperbolic",
-					  listener_Interpolation_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "DitherNone",
-					  listener_Dither_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "DitherNormal",
-					  listener_Dither_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "DitherMaximum",
-					  listener_Dither_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "CheckTypeDark",
-					  listener_CheckType_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "CheckTypeMidtone",
-					  listener_CheckType_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "CheckTypeLight",
-					  listener_CheckType_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "CheckTypeBlack",
-					  listener_CheckType_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "CheckTypeGray",
-					  listener_CheckType_cb, image_view);
-	bonobo_ui_component_add_listener (image_view->priv->uic, "CheckTypeWhite",
-					  listener_CheckType_cb, image_view);
+	value = gconf_client_get_int (image_view->priv->client, 
+				      GCONF_EOG_VIEW_INTERP_TYPE, 
+				      NULL);
+	set_ui_group_item (image_view, ui_id_strings_interp_type [value]);
+	for (i = 0; i < 4; i++) {
+		bonobo_ui_component_add_listener (image_view->priv->uic, ui_id_strings_interp_type [i],
+						  listener_Interpolation_cb, image_view);
+	}
+
+	value = gconf_client_get_int (image_view->priv->client, 
+				      GCONF_EOG_VIEW_DITHER, 
+				       NULL);
+	set_ui_group_item (image_view, ui_id_strings_dither [value]);
+	for (i = 0; i < 3; i++) {
+		bonobo_ui_component_add_listener (image_view->priv->uic, ui_id_strings_dither [i],
+						  listener_Dither_cb, image_view);
+	}
+
+	value = gconf_client_get_int (image_view->priv->client, 
+				      GCONF_EOG_VIEW_CHECK_TYPE, 
+				      NULL);
+	set_ui_group_item (image_view, ui_id_strings_check_type [value]);
+	for (i = 0; i < 6; i++) {
+		bonobo_ui_component_add_listener (image_view->priv->uic, ui_id_strings_check_type [i],
+						  listener_CheckType_cb, image_view);
+	}
+
+	value = gconf_client_get_int (image_view->priv->client, 
+				      GCONF_EOG_VIEW_CHECK_SIZE, 
+				      NULL);
+	set_ui_group_item (image_view, ui_id_strings_check_size [value]);
+	for (i = 0; i < 3; i++) {
+		bonobo_ui_component_add_listener (image_view->priv->uic, ui_id_strings_check_size [i],
+						  listener_CheckSize_cb, image_view);
+	}
+
 	bonobo_ui_component_add_listener (image_view->priv->uic, "CheckSizeSmall",
 					  listener_CheckSize_cb, image_view);
 	bonobo_ui_component_add_listener (image_view->priv->uic, "CheckSizeMedium",
@@ -1256,7 +1311,9 @@ eog_image_view_get_prop (BonoboPropertyBag *bag,
 
 		g_assert (arg->_type == TC_GNOME_EOG_Interpolation);
 
-		interp_type = image_view_get_interp_type (priv->image_view);
+		interp_type = (GdkInterpType) gconf_client_get_int (priv->client, 
+								    GCONF_EOG_VIEW_INTERP_TYPE, 
+								    NULL);
 		switch (interp_type) {
 		case GDK_INTERP_NEAREST:
 			eog_interp = GNOME_EOG_INTERPOLATION_NEAREST;
@@ -1279,7 +1336,9 @@ eog_image_view_get_prop (BonoboPropertyBag *bag,
 
 		g_assert (arg->_type == TC_GNOME_EOG_Dither);
 
-		dither = image_view_get_dither (image_view->priv->image_view);
+		dither = (GdkRgbDither) gconf_client_get_int (priv->client,
+							      GCONF_EOG_VIEW_DITHER,
+							      NULL);
 		switch (dither) {
 		case GDK_RGB_DITHER_NONE:
 			eog_dither = GNOME_EOG_DITHER_NONE;
@@ -1300,8 +1359,9 @@ eog_image_view_get_prop (BonoboPropertyBag *bag,
 
 		g_assert (arg->_type == TC_GNOME_EOG_CheckType);
 
-		check_type = image_view_get_check_type (priv->image_view);
-
+		check_type = (CheckType) gconf_client_get_int (priv->client,
+							       GCONF_EOG_VIEW_CHECK_TYPE,
+							       NULL);
 		switch (check_type) {
 		case CHECK_TYPE_DARK:
 			eog_check_type = GNOME_EOG_CHECK_TYPE_DARK;
@@ -1328,8 +1388,9 @@ eog_image_view_get_prop (BonoboPropertyBag *bag,
 
 		g_assert (arg->_type == TC_GNOME_EOG_CheckSize);
 
-		check_size = image_view_get_check_size (priv->image_view);
-
+		check_size = (CheckSize) gconf_client_get_int (priv->client,
+							       GCONF_EOG_VIEW_CHECK_SIZE,
+							       NULL);
 		switch (check_size) {
 		case CHECK_SIZE_SMALL:
 			eog_check_size = GNOME_EOG_CHECK_SIZE_SMALL;
@@ -1352,7 +1413,7 @@ eog_image_view_get_prop (BonoboPropertyBag *bag,
 		pixbuf = image_view_get_pixbuf (priv->image_view);
 		if (pixbuf) {
 			BONOBO_ARG_SET_INT (arg, gdk_pixbuf_get_width (pixbuf));
-			gdk_pixbuf_unref (pixbuf);
+			g_object_unref (pixbuf);
 		} else
 			BONOBO_ARG_SET_INT (arg, 0);
 		break;
@@ -1365,7 +1426,7 @@ eog_image_view_get_prop (BonoboPropertyBag *bag,
 		pixbuf = image_view_get_pixbuf (priv->image_view);
 		if (pixbuf) {
 			BONOBO_ARG_SET_INT (arg, gdk_pixbuf_get_height (pixbuf));
-			gdk_pixbuf_unref (pixbuf);
+			g_object_unref (pixbuf);
 		} else
 			BONOBO_ARG_SET_INT (arg, 0);
 		break;
@@ -1398,7 +1459,7 @@ eog_image_view_get_prop (BonoboPropertyBag *bag,
 				    gdk_pixbuf_get_width (pixbuf),
 				    gdk_pixbuf_get_height (pixbuf),
 				    zoom);
-			gdk_pixbuf_unref (pixbuf);
+			g_object_unref (pixbuf);
 		} else {
 			g_snprintf (text, 39, "%i%%", zoom); 
 		}
@@ -1449,8 +1510,10 @@ eog_image_view_set_prop (BonoboPropertyBag *bag,
 			g_assert_not_reached ();
 		}
 
-		image_view_set_interp_type (priv->image_view, interp_type);
-
+		gconf_client_set_int (priv->client, 
+				      GCONF_EOG_VIEW_INTERP_TYPE,
+				      (int) interp_type, 
+				      NULL);
 		break;
 	}
 	case PROP_DITHER: {
@@ -1472,8 +1535,10 @@ eog_image_view_set_prop (BonoboPropertyBag *bag,
 			g_assert_not_reached ();
 		}
 
-		image_view_set_dither (priv->image_view, dither);
-
+		gconf_client_set_int (priv->client, 
+				      GCONF_EOG_VIEW_DITHER,
+				      (int) dither, 
+				      NULL);
 		break;
 	}
 	case PROP_CHECK_TYPE: {
@@ -1504,8 +1569,10 @@ eog_image_view_set_prop (BonoboPropertyBag *bag,
 			g_assert_not_reached ();
 		}
 
-		image_view_set_check_type (priv->image_view, check_type);
-
+		gconf_client_set_int (priv->client, 
+				      GCONF_EOG_VIEW_CHECK_TYPE,
+				      (int) check_type, 
+				      NULL);
 		break;
 	}
 	case PROP_CHECK_SIZE: {
@@ -1527,8 +1594,10 @@ eog_image_view_set_prop (BonoboPropertyBag *bag,
 			g_assert_not_reached ();
 		}
 
-		image_view_set_check_size (priv->image_view, check_size);
-
+		gconf_client_set_int (priv->client, 
+				      GCONF_EOG_VIEW_CHECK_SIZE,
+				      (int) check_size, 
+				      NULL);
 		break;
 	}
 	default:
@@ -1673,137 +1742,14 @@ image_view_zoom_changed_cb (ImageView *image_view, gpointer data)
 	bonobo_arg_release (arg);
 }
 
-void
-eog_image_view_set_interpolation (EogImageView           *image_view,
-				  GNOME_EOG_Interpolation interpolation)
+GConfClient* 
+eog_image_view_get_client (EogImageView *image_view)
 {
-	BonoboArg *arg;
+	g_return_val_if_fail (EOG_IS_IMAGE_VIEW (image_view), NULL);
 
-	g_return_if_fail (image_view != NULL);
-	g_return_if_fail (EOG_IS_IMAGE_VIEW (image_view));
-
-	arg = bonobo_arg_new (TC_GNOME_EOG_Interpolation);
-	BONOBO_ARG_SET_GENERAL (arg, interpolation, TC_GNOME_EOG_Interpolation,
-				GNOME_EOG_Interpolation, NULL);
-
-	bonobo_pbclient_set_value (BONOBO_OBJREF (image_view->priv->property_bag),
-				       "interpolation", arg, NULL);
+	return image_view->priv->client;
 }
 
-GNOME_EOG_Interpolation
-eog_image_view_get_interpolation (EogImageView *image_view)
-{
-	BonoboArg *arg;
-
-	g_return_val_if_fail (image_view != NULL, 0);
-	g_return_val_if_fail (EOG_IS_IMAGE_VIEW (image_view), 0);
-
-	arg = bonobo_pbclient_get_value (BONOBO_OBJREF (image_view->priv->property_bag),
-					 "interpolation", NULL, NULL);
-	g_return_val_if_fail (arg, 0);
-	g_return_val_if_fail (arg->_type == TC_GNOME_EOG_Interpolation, 0);
-
-	return * (GNOME_EOG_Interpolation *) arg->_value;
-}
-
-void
-eog_image_view_set_dither (EogImageView    *image_view,
-			   GNOME_EOG_Dither dither)
-{
-	BonoboArg *arg;
-
-	g_return_if_fail (image_view != NULL);
-	g_return_if_fail (EOG_IS_IMAGE_VIEW (image_view));
-
-	arg = bonobo_arg_new (TC_GNOME_EOG_Dither);
-	BONOBO_ARG_SET_GENERAL (arg, dither, TC_GNOME_EOG_Dither,
-				GNOME_EOG_Dither, NULL);
-
-	bonobo_pbclient_set_value (BONOBO_OBJREF (image_view->priv->property_bag),
-				       "dither", arg, NULL);
-}
-
-GNOME_EOG_Dither
-eog_image_view_get_dither (EogImageView *image_view)
-{
-	BonoboArg *arg;
-
-	g_return_val_if_fail (image_view != NULL, 0);
-	g_return_val_if_fail (EOG_IS_IMAGE_VIEW (image_view), 0);
-
-	arg = bonobo_pbclient_get_value (BONOBO_OBJREF (image_view->priv->property_bag),
-					    "dither", NULL, NULL);
-	g_return_val_if_fail (arg, 0);
-	g_return_val_if_fail (arg->_type == TC_GNOME_EOG_Dither, 0);
-
-	return * (GNOME_EOG_Dither *) arg->_value;
-}
-
-void
-eog_image_view_set_check_type (EogImageView       *image_view,
-			       GNOME_EOG_CheckType check_type)
-{
-	BonoboArg *arg;
-
-	g_return_if_fail (image_view != NULL);
-	g_return_if_fail (EOG_IS_IMAGE_VIEW (image_view));
-
-	arg = bonobo_arg_new (TC_GNOME_EOG_CheckType);
-	BONOBO_ARG_SET_GENERAL (arg, check_type, TC_GNOME_EOG_CheckType,
-				GNOME_EOG_CheckType, NULL);
-
-	bonobo_pbclient_set_value (BONOBO_OBJREF (image_view->priv->property_bag),
-				       "check_type", arg, NULL);
-}
-
-GNOME_EOG_CheckType
-eog_image_view_get_check_type (EogImageView *image_view)
-{
-	BonoboArg *arg;
-
-	g_return_val_if_fail (image_view != NULL, 0);
-	g_return_val_if_fail (EOG_IS_IMAGE_VIEW (image_view), 0);
-
-	arg = bonobo_pbclient_get_value (BONOBO_OBJREF (image_view->priv->property_bag),
-					 "check_type", NULL, NULL);
-	g_return_val_if_fail (arg, 0);
-	g_return_val_if_fail (arg->_type == TC_GNOME_EOG_CheckType, 0);
-
-	return * (GNOME_EOG_CheckType *) arg->_value;
-}
-
-void
-eog_image_view_set_check_size (EogImageView       *image_view,
-			       GNOME_EOG_CheckSize check_size)
-{
-	BonoboArg *arg;
-
-	g_return_if_fail (image_view != NULL);
-	g_return_if_fail (EOG_IS_IMAGE_VIEW (image_view));
-
-	arg = bonobo_arg_new (TC_GNOME_EOG_CheckSize);
-	BONOBO_ARG_SET_GENERAL (arg, check_size, TC_GNOME_EOG_CheckSize,
-				GNOME_EOG_CheckSize, NULL);
-
-	bonobo_pbclient_set_value (BONOBO_OBJREF (image_view->priv->property_bag),
-				       "check_size", arg, NULL);
-}
-
-GNOME_EOG_CheckSize
-eog_image_view_get_check_size (EogImageView *image_view)
-{
-	BonoboArg *arg;
-
-	g_return_val_if_fail (image_view != NULL, 0);
-	g_return_val_if_fail (EOG_IS_IMAGE_VIEW (image_view), 0);
-
-	arg = bonobo_pbclient_get_value (BONOBO_OBJREF (image_view->priv->property_bag),
-					 "check_size", NULL, NULL);
-	g_return_val_if_fail (arg, 0);
-	g_return_val_if_fail (arg->_type == TC_GNOME_EOG_CheckSize, 0);
-
-	return * (GNOME_EOG_CheckSize *) arg->_value;
-}
 
 /* ***************************************************************************
  * Constructor, destructor, etc.
@@ -1824,13 +1770,15 @@ eog_image_view_destroy (BonoboObject *object)
 	image_view = EOG_IMAGE_VIEW (object);
 	priv = image_view->priv;
 
+	gconf_client_notify_remove (priv->client, priv->interp_type_notify_id);
+	gconf_client_notify_remove (priv->client, priv->dither_notify_id);
+	gconf_client_notify_remove (priv->client, priv->check_type_notify_id);
+	gconf_client_notify_remove (priv->client, priv->check_size_notify_id);
 	g_object_unref (G_OBJECT (priv->client));
 
 	bonobo_object_unref (BONOBO_OBJECT (priv->property_bag));
 	bonobo_object_unref (BONOBO_OBJECT (priv->image));
 	bonobo_object_unref (BONOBO_OBJECT (priv->uic));
-
-	gtk_widget_unref (image_view->priv->ui_image);
 	
 	if (getenv ("DEBUG_EOG"))
 		g_message ("EogImageView destroyed.");
@@ -1936,6 +1884,103 @@ property_control_get_cb (BonoboPropertyControl *property_control,
 	return control;
 }
 
+static void
+interp_type_changed_cb (GConfClient *client,
+			guint        cnxn_id,
+			GConfEntry  *entry,
+			gpointer     user_data)
+{
+	EogImageView *view;
+	GdkInterpType interpolation;
+
+	view = EOG_IMAGE_VIEW (user_data);
+	
+	if (entry->value != NULL && entry->value->type == GCONF_VALUE_INT) {
+		interpolation = (GdkInterpType) gconf_value_get_int (entry->value);
+	}
+	else {
+		interpolation = GDK_INTERP_BILINEAR;
+	}
+
+	image_view_set_interp_type (view->priv->image_view, interpolation);
+	bonobo_event_source_notify_listeners (view->priv->property_bag->es,
+					      "interpolation", NULL, NULL);
+	set_ui_group_item (view, ui_id_strings_interp_type [interpolation]);
+}
+
+static void
+dither_changed_cb (GConfClient *client,
+		   guint        cnxn_id,
+		   GConfEntry  *entry,
+		   gpointer     user_data)
+{
+	EogImageView *view;
+	GdkRgbDither dither;
+
+	view = EOG_IMAGE_VIEW (user_data);
+	
+	if (entry->value != NULL && entry->value->type == GCONF_VALUE_INT) {
+		dither = (GdkRgbDither) gconf_value_get_int (entry->value);
+	} 
+	else {
+		dither = GDK_RGB_DITHER_NONE;
+	}
+
+	image_view_set_dither (view->priv->image_view, dither);
+	bonobo_event_source_notify_listeners (view->priv->property_bag->es,
+					      "dither", NULL, NULL);
+	set_ui_group_item (view, ui_id_strings_dither [dither]);
+}
+
+static void
+check_type_changed_cb (GConfClient *client,
+		       guint        cnxn_id,
+		       GConfEntry  *entry,
+		       gpointer     user_data)
+{
+	EogImageView *view;
+	CheckType check_type;
+
+	view = EOG_IMAGE_VIEW (user_data);
+	
+	if (entry->value != NULL && entry->value->type == GCONF_VALUE_INT) {
+		check_type = (CheckType) gconf_value_get_int (entry->value);
+	}
+	else {
+		check_type = CHECK_TYPE_MIDTONE;
+	}
+
+	image_view_set_check_type (view->priv->image_view, check_type);
+	bonobo_event_source_notify_listeners (view->priv->property_bag->es,
+					      "check_type", NULL, NULL);
+	set_ui_group_item (view, ui_id_strings_check_type [check_type]);
+}
+
+static void
+check_size_changed_cb (GConfClient *client,
+		       guint        cnxn_id,
+		       GConfEntry  *entry,
+		       gpointer     user_data)
+{
+	EogImageView *view;
+	CheckSize check_size;
+
+	view = EOG_IMAGE_VIEW (user_data);
+	
+	if (entry->value != NULL && entry->value->type == GCONF_VALUE_INT) {
+		check_size = (CheckSize) gconf_value_get_int (entry->value);
+	}
+	else {
+		check_size = CHECK_SIZE_MEDIUM;
+	}
+
+	image_view_set_check_size (view->priv->image_view, check_size);
+	bonobo_event_source_notify_listeners (view->priv->property_bag->es,
+					      "check_size", NULL, NULL);
+	set_ui_group_item (view, ui_id_strings_check_size [check_size]);
+}
+
+
 EogImageView *
 eog_image_view_construct (EogImageView       *image_view,
 			  EogImage           *image,
@@ -1946,11 +1991,14 @@ eog_image_view_construct (EogImageView       *image_view,
 	g_return_val_if_fail (image != NULL, NULL);
 	g_return_val_if_fail (EOG_IS_IMAGE (image), NULL);
 
-	/* Make sure GConf is initialized */
+	/* setup gconf stuff */
 	if (!gconf_is_initialized ())
-		gconf_init (0, NULL, NULL);
-	
+		gconf_init (0, NULL, NULL);	
 	image_view->priv->client = gconf_client_get_default ();
+	gconf_client_add_dir (image_view->priv->client,
+			      GCONF_EOG_VIEW_DIR,
+			      GCONF_CLIENT_PRELOAD_ONELEVEL,
+			      NULL);
 	
 	image_view->priv->image = image;
 	bonobo_object_ref (BONOBO_OBJECT (image_view->priv->image));
@@ -1963,20 +2011,53 @@ eog_image_view_construct (EogImageView       *image_view,
 	image_view->priv->ui_image = ui_image_new ();
 	gtk_widget_show (image_view->priv->ui_image);
 
-	image_view->priv->image_view = IMAGE_VIEW (ui_image_get_image_view (UI_IMAGE (image_view->priv->ui_image)));
+	image_view->priv->image_view = 
+		IMAGE_VIEW (ui_image_get_image_view (UI_IMAGE (image_view->priv->ui_image)));
 	g_signal_connect (G_OBJECT (image_view->priv->image_view), 
 			  "zoom_changed", 
 			  (GCallback) image_view_zoom_changed_cb, 
 			  image_view);
 
-	/* Some sensible defaults */
-	image_view_set_scroll      (image_view->priv->image_view,
-			            SCROLL_TWO_PASS);
-	image_view_set_interp_type (image_view->priv->image_view,
-			            GDK_INTERP_BILINEAR);
-	image_view_set_dither      (image_view->priv->image_view,
-			            GDK_RGB_DITHER_MAX);
+	/* get preference values from gconf and add listeners */
+	image_view_set_scroll  (image_view->priv->image_view, SCROLL_TWO_PASS);
 
+	image_view_set_interp_type (image_view->priv->image_view,
+			            (GdkInterpType) gconf_client_get_int (image_view->priv->client,
+									  GCONF_EOG_VIEW_INTERP_TYPE,
+									  NULL));
+	image_view_set_dither (image_view->priv->image_view,
+			       (GdkRgbDither) gconf_client_get_int (image_view->priv->client,
+								    GCONF_EOG_VIEW_DITHER,
+								    NULL));
+	image_view_set_check_type (image_view->priv->image_view,
+				   (CheckType) gconf_client_get_int (image_view->priv->client,
+								     GCONF_EOG_VIEW_CHECK_TYPE,
+								     NULL));
+	image_view_set_check_size (image_view->priv->image_view,
+				   (CheckSize) gconf_client_get_int (image_view->priv->client,
+								     GCONF_EOG_VIEW_CHECK_SIZE,
+								     NULL));
+	image_view->priv->interp_type_notify_id = 
+		gconf_client_notify_add (image_view->priv->client,
+					 GCONF_EOG_VIEW_INTERP_TYPE, 
+					 interp_type_changed_cb,
+					 image_view, NULL, NULL);
+	image_view->priv->dither_notify_id = 
+		gconf_client_notify_add (image_view->priv->client,
+					 GCONF_EOG_VIEW_DITHER, 
+					 dither_changed_cb,
+					 image_view, NULL, NULL);
+	image_view->priv->check_type_notify_id = 
+		gconf_client_notify_add (image_view->priv->client,
+					 GCONF_EOG_VIEW_CHECK_TYPE, 
+					 check_type_changed_cb,
+					 image_view, NULL, NULL);
+	image_view->priv->check_size_notify_id = 
+		gconf_client_notify_add (image_view->priv->client,
+					 GCONF_EOG_VIEW_CHECK_SIZE, 
+					 check_size_changed_cb,
+					 image_view, NULL, NULL);
+	
 	image_set_image_cb (image, image_view);
 
 	/* Property Bag */
